# Doesn't build with libcdio >= 1.1.0
# https://github.com/MusicPlayerDaemon/MPD/issues/173
%bcond_with cdio

%define build_plf 0
%if "%{?distro_section}" == "tainted"
%define build_plf 1
%endif

Name:           mpd
Version:        0.20.23
Release:        %mkrel 3

Summary:        MPD, the Music Player Daemon
License:        GPLv2+
Group:          Sound/Players
Url:            http://www.musicpd.org/
Source0:        http://www.musicpd.org/download/mpd/stable/%{name}-%{version}.tar.xz
Source1:        %{name}.conf
Source2:        %{name}.init
Source3:        %{name}.logrotate
Source4:        README.urpmi

BuildRequires: pkgconfig(alsa) >= 0.9.0
BuildRequires: pkgconfig(ao)
BuildRequires: pkgconfig(audiofile) >= 0.1.7
BuildRequires: pkgconfig(avahi-client)
BuildRequires: pkgconfig(avahi-glib)
BuildRequires: boost-devel
BuildRequires: pkgconfig(flac) >= 1.1
BuildRequires: pkgconfig(fluidsynth) >= 1.1
BuildRequires: pkgconfig(glib-2.0) >= 2.16
BuildRequires: pkgconfig(gthread-2.0)
BuildRequires: pkgconfig(id3tag)
BuildRequires: pkgconfig(jack) >= 0.100
BuildRequires: pkgconfig(libavcodec) >= 52.20
BuildRequires: pkgconfig(libavformat) >= 52.31
BuildRequires: pkgconfig(libavutil) >= 49.15
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(libffado)
BuildRequires: pkgconfig(libmms) >= 0.4
BuildRequires: pkgconfig(libmodplug)
BuildRequires: pkgconfig(libmpg123)
BuildRequires: pkgconfig(libpulse)
BuildRequires: pkgconfig(libsidplay2)
BuildRequires: pkgconfig(libsidutils)
BuildRequires: pkgconfig(libsoup-2.4)
BuildRequires: pkgconfig(systemd)
BuildRequires: pkgconfig(mad)
BuildRequires: pkgconfig(ogg)
BuildRequires: pkgconfig(openal)
BuildRequires: pkgconfig(samplerate) >= 0.0.15
BuildRequires: pkgconfig(shout)
BuildRequires: pkgconfig(sndfile)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(vorbis)
BuildRequires: pkgconfig(vorbisenc)
BuildRequires: pkgconfig(vorbisfile)
BuildRequires: pkgconfig(wavpack)
BuildRequires: pkgconfig(yajl) >= 2.0
BuildRequires: pkgconfig(zziplib) >= 0.13
BuildRequires: libmpcdec-devel
BuildRequires: lame-devel
%if %build_plf
BuildRequires: libfaad2-devel
%endif

%if %{with cdio}
BuildRequires: pkgconfig(libcdio_paranoia)
BuildRequires: pkgconfig(libiso9660)
%endif

Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
Music Player Daemon (MPD) allows remote access for playing music (MP3, Ogg
Vorbis, FLAC, Mod, and wave files) and managing playlists. MPD is designed
for integrating a computer into a stereo system that provides control for music
playback over a local network. It is also makes a great desktop music player,
especially if your a console junkie, like frontend options, or restart X often.
%if %build_plf
This package is in the 'tainted' section because it is built with AAC support
of libfaad2.
%endif

%prep
%setup -q

%build
autoreconf -fi
%configure2_5x \
	--enable-cdio-paranoia=%{?with_cdio:yes}%{?!with_cdio:no} \
	--enable-iso9660=%{?with_cdio:yes}%{?!with_cdio:no} \
	--with-systemdsystemunitdir=%_unitdir
%make_build

%install
%make_install

mkdir -p %{buildroot}/var/lib/mpd
touch %{buildroot}/%{_localstatedir}/lib/mpd/mpd.db
touch %{buildroot}/%{_localstatedir}/lib/mpd/mpdstate
mkdir -p %{buildroot}/var/log/mpd
touch %{buildroot}/var/log/mpd/mpd.log
touch %{buildroot}/var/log/mpd/mpd.error
mkdir -p %{buildroot}/%{_localstatedir}/lib/mpd/playlists
mkdir -p %{buildroot}/%{_localstatedir}/lib/mpd/music

install -D %{SOURCE1} %{buildroot}/etc/mpd.conf
install -D %{SOURCE2} %{buildroot}/%{_initrddir}/%{name}
install -D -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install %{SOURCE4} doc/README.urpmi
rm -rf %{buildroot}/%{_docdir}/mpd

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/mpd 0755 mpd audio
EOF

%pre
%_pre_useradd %name %{_localstatedir}/lib/%{name} /bin/false
usermod -g audio %{name}

%post
%_tmpfilescreate %{name}
if [ $1 -eq 1 ]
then
%create_ghostfile %{_localstatedir}/lib/mpd/mpd.db mpd audio 644
%create_ghostfile %{_localstatedir}/lib/mpd/mpdstate mpd audio 644
%create_ghostfile /var/log/mpd/mpd.log mpd audio 644
%create_ghostfile /var/log/mpd/mpd.error mpd audio 644
fi
#echo If you want to run mpd as a service, please read
#echo /usr/share/doc/mpd-%%{version}/README.MDK
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files
%doc README.md AUTHORS NEWS doc/mpdconf.example doc/*.urpmi
%{_bindir}/%{name}
%{_iconsdir}/hicolor/scalable/apps/mpd.svg
%{_mandir}/man1/mpd.1.xz
%{_mandir}/man5/mpd.conf.5.xz
%{_unitdir}/mpd.service
%{_unitdir}/mpd.socket
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(-,mpd,root) %config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_initrddir}/%{name}
%{_tmpfilesdir}/%{name}.conf
%defattr(644,mpd,audio)
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd/music
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd/playlists
%ghost %{_localstatedir}/lib/mpd/mpd.db
%ghost %{_localstatedir}/lib/mpd/mpdstate
%attr(755,mpd,audio) %dir /var/log/mpd
%ghost /var/log/mpd/mpd.log
%ghost /var/log/mpd/mpd.error


%changelog
* Mon Jan 14 2019 luigiwalser <luigiwalser> 0.20.23-3.mga7
+ Revision: 1356815
- rebuild for fluidsynth

* Fri Jan 11 2019 daviddavid <daviddavid> 0.20.23-2.mga7.tainted
+ Revision: 1354743
- rebuild for new icu

* Wed Oct 31 2018 zezinho <zezinho> 0.20.23-1.mga7.tainted
+ Revision: 1326981
- new bugfix version 0.20.23

* Fri Oct 26 2018 zezinho <zezinho> 0.20.22-1.mga7.tainted
+ Revision: 1326010
- new version 0.20.22

* Fri Sep 21 2018 zezinho <zezinho> 0.20.21-1.mga7.tainted
+ Revision: 1294782
- new version 0.20.21

* Tue Aug 28 2018 daviddavid <daviddavid> 0.20.18-2.mga7.tainted
+ Revision: 1255146
- rebuild for new icu

* Mon Apr 23 2018 zezinho <zezinho> 0.20.18-1.mga7.tainted
+ Revision: 1221730
- new version 0.20.18

* Wed Feb 21 2018 kekepower <kekepower> 0.20.17-1.mga7
+ Revision: 1203840
- Update to version 0.20.17

* Sun Jan 14 2018 wally <wally> 0.20.13-2.mga7
+ Revision: 1193111
- disable libcdio-paranoia and iso9660 support for now as mpd isn't compatible with libcdio >= 1.1.0

* Sat Dec 30 2017 zezinho <zezinho> 0.20.13-1.mga7.tainted
+ Revision: 1187606
- new version

* Fri Dec 29 2017 wally <wally> 0.19.21-5.mga7
+ Revision: 1186994
- rebuild for new icu

* Tue May 02 2017 akien <akien> 0.19.21-4.mga6
+ Revision: 1098367
- Rebuild for ffmpeg 3.3

* Mon Mar 20 2017 akien <akien> 0.19.21-3.mga6.tainted
+ Revision: 1093678
- Rebuild for icu 58.2

* Wed Mar 08 2017 akien <akien> 0.19.21-2.mga6.tainted
+ Revision: 1089882
- Rebuild for ffmpeg 3.2.4

* Sun Jan 01 2017 luigiwalser <luigiwalser> 0.19.21-1.mga6.tainted
+ Revision: 1079367
- 0.19.21

* Sat Jun 25 2016 daviddavid <daviddavid> 0.19.15-7.mga6.tainted
+ Revision: 1037618
- submit to tainted/release

* Sat Jun 18 2016 luigiwalser <luigiwalser> 0.19.15-6.mga6
+ Revision: 1022616
- rebuild with fix libmad

* Wed Jun 08 2016 daviddavid <daviddavid> 0.19.15-5.mga6
+ Revision: 1020835
- submit to tainted/release

* Wed Jun 08 2016 tv <tv> 0.19.15-4.mga6
+ Revision: 1020780
- adjust BRs for latest systemd

* Fri May 20 2016 daviddavid <daviddavid> 0.19.15-3.mga6.tainted
+ Revision: 1017247
- rebuild for tainted/release

* Thu May 19 2016 pterjan <pterjan> 0.19.15-2.mga6
+ Revision: 1017029
- Rebuild for icu

* Sat May 14 2016 shlomif <shlomif> 0.19.15-1.mga6
+ Revision: 1015488
- New version + rebuild for ICU

* Sat Mar 12 2016 shlomif <shlomif> 0.19.13-1.mga6.tainted
+ Revision: 989647
- Add missing BR on boost-devel
- New version 0.19.13

* Mon Feb 15 2016 umeabot <umeabot> 0.18.8-6.mga6.tainted
+ Revision: 961528
- Mageia 6 Mass Rebuild

* Sat Aug 29 2015 cjw <cjw> 0.18.8-5.mga6
+ Revision: 870761
- fix build (with gcc 5)

* Thu Jul 16 2015 sander85 <sander85> 0.18.8-4.mga6.tainted
+ Revision: 854720
- Rebuild for new libcdio

* Fri Nov 14 2014 akien <akien> 0.18.8-3.mga5.tainted
+ Revision: 797079
- Rebuild for ffmpeg 2.4

* Thu Sep 04 2014 colin <colin> 0.18.8-2.mga5.tainted
+ Revision: 672049
- Rebuild for new systemd

* Thu Feb 20 2014 jquelin <jquelin> 0.18.8-1.mga5.tainted
+ Revision: 595047
- update to 0.18.8
+ luigiwalser <luigiwalser>
- rebuild for libcdio

* Sun Sep 01 2013 fwang <fwang> 0.17.4-3.mga4.tainted
+ Revision: 473954
- rebuild for new libcdio

* Mon Jul 15 2013 fwang <fwang> 0.17.4-2.mga4.tainted
+ Revision: 454468
- rebuild for new ffmpeg
- rebuild for new ffmpeg

* Wed Jun 26 2013 jquelin <jquelin> 0.17.4-1.mga4.tainted
+ Revision: 446842
- update to 0.17.4

* Sun Mar 24 2013 colin <colin> 0.17.3-5.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Jan 13 2013 luigiwalser <luigiwalser> 0.17.3-4.mga3.tainted
+ Revision: 362603
- add tmpfiles config for /run/mpd
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.17.3-2.mga3.tainted
+ Revision: 342346
- br sidplay2

* Tue Jan 08 2013 fwang <fwang> 0.17.3-1.mga3
+ Revision: 342340
- more br
- specify systemdunitdir
- add more br
- cleanup br
- new version 0.17.3

* Tue Jan 08 2013 fwang <fwang> 0.17.1-3.mga3.tainted
+ Revision: 341833
- rebuild for new ffmpeg

* Tue Nov 27 2012 jquelin <jquelin> 0.17.1-2.mga3
+ Revision: 322330
- rpm group change

* Fri Aug 17 2012 fedya <fedya> 0.17.1-1.mga3
+ Revision: 281780
- rpmlint warning fix
- version update 0.17.1

* Mon Jul 02 2012 jquelin <jquelin> 0.17-1.mga3.tainted
+ Revision: 266725
- update to 0.17

* Thu Jun 07 2012 jquelin <jquelin> 0.16.8-1.mga3.tainted
+ Revision: 256763
- update to 0.6.8

* Sat Apr 28 2012 tmb <tmb> 0.16.6-2.mga2.tainted
+ Revision: 233801
- Require rpm-helper >= 0.24.8-1 for systemd support

* Mon Jan 23 2012 fwang <fwang> 0.16.6-1.mga2
+ Revision: 200251
- new version 0.16.6

* Thu Jan 12 2012 fwang <fwang> 0.16.5-2.mga2.tainted
+ Revision: 195275
- rebuild for new audiofile

* Thu Nov 10 2011 jquelin <jquelin> 0.16.5-1.mga2
+ Revision: 166163
- update to 0.16.5
- make mpd.tainted play m4a files (mga#3290)

* Sat Sep 17 2011 jquelin <jquelin> 0.16.3-3.mga2
+ Revision: 144565
- fix bug#1630 - remove config/runtime options that are no longer supported

* Thu Jul 14 2011 kharec <kharec> 0.16.3-2.mga2
+ Revision: 124123
- fix README.urpmi (fix #1630)

* Mon Jul 11 2011 kharec <kharec> 0.16.3-1.mga2
+ Revision: 122136
- new version 0.16.3

* Sun May 29 2011 cjw <cjw> 0.16.2-2.mga1.tainted
+ Revision: 100690
- add support for tainted builds

* Fri Apr 15 2011 shikamaru <shikamaru> 0.16.2-1.mga1
+ Revision: 85901
- New version 0.16.2
- retab (mix use of space and tabs)

* Tue Mar 01 2011 jquelin <jquelin> 0.16.1-1.mga1
+ Revision: 62012
- update to 0.16.1

* Sun Jan 09 2011 jquelin <jquelin> 0.15.13-1.mga1
+ Revision: 1714
- imported package mpd

